Helpers
-------

Problematic
^^^^^^^^^^^

How can we avoid writing the same thing every time?

Documentation
^^^^^^^^^^^^^

.. automodule:: PyFunceble.helpers
   :members:
   :private-members:


:code:`Command()`
"""""""""""""""""

.. autoclass:: PyFunceble.helpers.Command
    :members:
    :private-members:

:code:`Dict()`
""""""""""""""

.. autoclass:: PyFunceble.helpers.Dict
    :members:
    :private-members:

:code:`Directory()`
"""""""""""""""""""

.. autoclass:: PyFunceble.helpers.Directory
    :members:
    :private-members:

:code:`Download()`
""""""""""""""""""

.. autoclass:: PyFunceble.helpers.Download
    :members:
    :private-members:

:code:`File()`
""""""""""""""

.. autoclass:: PyFunceble.helpers.File
    :members:
    :private-members:

:code:`Hash()`
""""""""""""""

.. autoclass:: PyFunceble.helpers.Hash
    :members:
    :private-members:

:code:`List()`
""""""""""""""

.. autoclass:: PyFunceble.helpers.List
    :members:
    :private-members:

:code:`Merge()`
"""""""""""""""

.. autoclass:: PyFunceble.helpers.Merge
    :members:
    :private-members:

:code:`Regex()`
"""""""""""""""

.. autoclass:: PyFunceble.helpers.Regex
    :members:
    :private-members:

